@@ -6,14 +6,10 @@
 
 #[macro_use]
 extern crate lazy_static;
-
 #[macro_use]
 extern crate serde_json;
-
 pub use error::{Error, Result};
 
-pub mod runtime;
-
 #[cfg(feature = "mssql")]
 mod mssql;
 /// database
@@ -32,3 +28,4 @@ pub mod decode;
 pub mod results;
 pub mod value;
 pub mod types;
+pub use types::*;
