@@ -1,8 +1,8 @@
 use std::ops::{Add, Deref, DerefMut};
 use std::str::FromStr;
 use std::time::SystemTime;
-use bson2::{Bson, DateTime};
-use bson2::spec::BinarySubtype;
+use rbson::{Bson, DateTime};
+use rbson::spec::BinarySubtype;
 use chrono::{Local, NaiveDateTime, Utc};
 use serde::{Deserializer, Serializer};
 use serde::de::Error;
@@ -13,7 +13,7 @@ pub struct DateTimeNative {
     pub inner: chrono::NaiveDateTime,
 }
 
-impl From<bson2::DateTime> for DateTimeNative {
+impl From<rbson::DateTime> for DateTimeNative {
     fn from(arg: DateTime) -> Self {
         Self {
             inner: arg.to_chrono().with_timezone(&chrono::Local).naive_local(),
@@ -126,7 +126,7 @@ impl DerefMut for DateTimeNative {
 impl DateTimeNative {
     /// Returns a [`DateTime`] which corresponds to the current date and time.
     pub fn now() -> DateTimeNative {
-        let dt = bson2::DateTime::now();
+        let dt = rbson::DateTime::now();
         Self {
             inner: dt.to_chrono().naive_local()
         }
@@ -148,8 +148,8 @@ mod test {
     #[test]
     fn test_native() {
         let dt = DateTimeNative::now();
-        let s = bson2::to_bson(&dt).unwrap();
-        let dt_new: DateTimeNative = bson2::from_bson(s).unwrap();
+        let s = rbson::to_bson(&dt).unwrap();
+        let dt_new: DateTimeNative = rbson::from_bson(s).unwrap();
         println!("{},{}", dt.timestamp_millis(), dt_new.timestamp_millis());
         assert_eq!(dt, dt_new);
     }
@@ -158,16 +158,16 @@ mod test {
     fn test_utc() {
         let dt = DateTimeNative::now();
         println!("{}",dt);
-        let s = bson2::to_bson(&dt).unwrap();
-        let dt_new: DateTimeNative = bson2::from_bson(s).unwrap();
+        let s = rbson::to_bson(&dt).unwrap();
+        let dt_new: DateTimeNative = rbson::from_bson(s).unwrap();
         println!("{},{}", dt.timestamp_millis(), dt_new.timestamp_millis());
         assert_eq!(dt, dt_new);
     }
 
     #[test]
     fn test_decode() {
-        let s = bson2::Bson::String("2015-09-18T23:56:04".to_string());
-        let dt_new: DateTimeNative = bson2::from_bson(s).unwrap();
+        let s = rbson::Bson::String("2015-09-18T23:56:04".to_string());
+        let dt_new: DateTimeNative = rbson::from_bson(s).unwrap();
         println!("{},{}", 1442620564000i64, dt_new.timestamp_millis());
         assert_eq!(1442620564000i64, dt_new.timestamp_millis());
     }
@@ -175,9 +175,9 @@ mod test {
     #[test]
     fn test_ser_de() {
         let b = DateTimeNative::now();
-        let bsons = bson2::to_bson(&b).unwrap();
+        let bsons = rbson::to_bson(&b).unwrap();
         println!("{}",bsons);
-        let b_de: DateTimeNative = bson2::from_bson(bsons).unwrap();
+        let b_de: DateTimeNative = rbson::from_bson(bsons).unwrap();
         assert_eq!(b, b_de);
     }
 }
\ No newline at end of file
