@@ -1,7 +1,7 @@
 use std::ops::{Deref, DerefMut};
 use std::str::FromStr;
-use bson2::Bson;
-use bson2::spec::BinarySubtype;
+use rbson::Bson;
+use rbson::spec::BinarySubtype;
 use serde::{Deserializer, Serializer};
 use chrono::Utc;
 use serde::de::Error;
@@ -93,7 +93,7 @@ impl DateTimeUtc {
     /// Returns a [`DateTime`] which corresponds to the current date and time.
     pub fn now() -> DateTimeUtc {
         let utc = Utc::now();
-        let dt = bson2::DateTime::from_millis(utc.timestamp_millis());
+        let dt = rbson::DateTime::from_millis(utc.timestamp_millis());
         Self {
             inner: dt.to_chrono()
         }
@@ -115,8 +115,8 @@ mod test {
     #[test]
     fn test_ser_de() {
         let b = DateTimeUtc::now();
-        let bsons = bson2::to_bson(&b).unwrap();
-        let b_de: DateTimeUtc = bson2::from_bson(bsons).unwrap();
+        let bsons = rbson::to_bson(&b).unwrap();
+        let b_de: DateTimeUtc = rbson::from_bson(bsons).unwrap();
         assert_eq!(b, b_de);
     }
 }
\ No newline at end of file
