@@ -1,8 +1,8 @@
 use std::borrow::BorrowMut;
 use std::ops::{Deref, DerefMut};
 use std::slice::IterMut;
-use bson2::{Binary, Bson, Document};
-use bson2::spec::BinarySubtype;
+use rbson::{Binary, Bson, Document};
+use rbson::spec::BinarySubtype;
 use serde::{Deserializer, Serialize, Serializer};
 use serde::de::{DeserializeOwned, Error, Expected};
 use serde_json::ser::Formatter;
@@ -134,8 +134,8 @@ mod test {
         let b = Json {
             inner: 1
         };
-        let bsons = bson2::to_bson(&b).unwrap();
-        let b_de: Json<i32> = bson2::from_bson(bsons).unwrap();
+        let bsons = rbson::to_bson(&b).unwrap();
+        let b_de: Json<i32> = rbson::from_bson(bsons).unwrap();
         assert_eq!(b, b_de);
     }
 }
\ No newline at end of file
