@@ -7,8 +7,8 @@ pub const BINARY_SUBTYPE_JSON: u8 = 0x90;
 pub mod json;
 
 use std::fmt::Formatter;
-use bson2::Bson;
-use bson2::spec::BinarySubtype;
+use rbson::Bson;
+use rbson::spec::BinarySubtype;
 pub use json::*;
 
 pub mod uuids;
