@@ -1,7 +1,7 @@
 use std::alloc::Layout;
 use std::ops::{Deref, DerefMut};
-use bson2::Bson;
-use bson2::spec::BinarySubtype;
+use rbson::Bson;
+use rbson::spec::BinarySubtype;
 use serde::{Deserializer, Serializer};
 use serde::de::Error;
 use sqlx_core::types::time;
@@ -66,23 +66,23 @@ impl<'de> serde::Deserialize<'de> for TimestampZ {
 }
 
 impl TimestampZ {
-    pub fn as_timestamp(arg: &bson2::Timestamp) -> i64 {
+    pub fn as_timestamp(arg: &rbson::Timestamp) -> i64 {
         let upper = (arg.time.to_le() as u64) << 32;
         let lower = arg.increment.to_le() as u64;
         (upper | lower) as i64
     }
 
-    pub fn from_le_i64(val: i64) -> bson2::Timestamp {
+    pub fn from_le_i64(val: i64) -> rbson::Timestamp {
         let ts = val.to_le();
-        bson2::Timestamp {
+        rbson::Timestamp {
             time: ((ts as u64) >> 32) as u32,
             increment: (ts & 0xFFFF_FFFF) as u32,
         }
     }
 }
 
-impl From<bson2::Timestamp> for TimestampZ {
-    fn from(data: bson2::Timestamp) -> Self {
+impl From<rbson::Timestamp> for TimestampZ {
+    fn from(data: rbson::Timestamp) -> Self {
         let offset = time::OffsetDateTime::from_unix_timestamp(TimestampZ::as_timestamp(&data));
         Self {
             inner: offset
@@ -162,8 +162,8 @@ mod test {
     #[test]
     fn test_native() {
         let dt = TimestampZ::now_utc();
-        let s = bson2::to_bson(&dt).unwrap();
-        let dt_new: TimestampZ = bson2::from_bson(s).unwrap();
+        let s = rbson::to_bson(&dt).unwrap();
+        let dt_new: TimestampZ = rbson::from_bson(s).unwrap();
         println!("{},{}", dt.timestamp_millis(), dt_new.timestamp_millis());
         assert_eq!(dt, dt_new);
     }
@@ -171,8 +171,8 @@ mod test {
     #[test]
     fn test_ser_de() {
         let b = TimestampZ::now();
-        let bsons = bson2::to_bson(&b).unwrap();
-        let b_de: TimestampZ = bson2::from_bson(bsons).unwrap();
+        let bsons = rbson::to_bson(&b).unwrap();
+        let b_de: TimestampZ = rbson::from_bson(bsons).unwrap();
         assert_eq!(b, b_de);
     }
 }
